@@ -1,7 +1,7 @@
 package Rope;
 
 use 5.006; use strict; use warnings;
-our $VERSION = '0.22';
+our $VERSION = '0.23';
 use Rope::Object;
 my (%META, %PRO);
 our @ISA;
@@ -498,7 +498,7 @@ Rope - Tied objects
 
 =head1 VERSION
 
-Version 0.22
+Version 0.23
 
 =cut
 
@@ -965,7 +965,8 @@ With Rope you can also create chained and factory properties. A chained property
 		[Str, Str] => sub {
 			$_[0]->reset() if $_[1] eq 'reset';
 			push @{$_[0]->found}, $_[2];
-		}
+		},
+		sub { return 'fallback' }
 	);
 
 	chain add => 'ephesus' => sub {
@@ -1000,7 +1001,14 @@ With Rope you can also create chained and factory properties. A chained property
 
 	$asia->thyatira();
 
-Notes: If you chain into a factory, the factory will accept not the passed params but the response from the 'last' chain. Returning undef is a hack that only works when chaining a chain, your first defined chain in this approach should return either the passed request params or some valid response. Factories cannot currently handle 'undef' explicitly but this may change in the future. If you define multiple factories with the same name, the initial will be extended not re-written, so extending a factory or chain should work accross inheritance.
+Notes: If you chain into a factory, the factory will accept not the passed params but the response from the 'last' chain. Returning undef is a hack that only works when chaining a chain, your first defined chain in this approach should return either the passed request params or some valid response.  If you define multiple factories with the same name, the initial will be extended not re-written, so extending a factory or chain should work accross inheritance. If you would like to extend and existing et chain two factories together you can by passing an integer to the factory you would like to create or extend, you must understand the order they are instantiated for this to work as expected.
+
+	factory add => 1 => ( # using the index 0 would extend the existing this extends after a new 'factory'
+		[ArrayRef] => sub {
+			push @{$_[1]}, 'Sardis';
+			return $_[1];
+		},
+	);
 
 =head1 AUTOLOADING
 
