@@ -22,10 +22,13 @@ sub import {
 	}
 	$PRO{keyword}($caller, 'factory', sub {
 		my ($name, @factory) = @_;
-		my ($meta, $fact, $exists, $extends) = (Rope->get_meta($caller));
+		my ($meta, $ind, $fact, $exists, $extends) = (
+			Rope->get_meta($caller),
+			(! ref $factory[0] ? shift @factory : 0)
+		);
 		if ($meta->{properties}->{$name}) {
-			if ($meta->{properties}->{$name}->{fact}) {
-				$fact = $meta->{properties}->{$name}->{fact};
+			if ($meta->{properties}->{$name}->{fact}->[$ind]) {
+				$fact = $meta->{properties}->{$name}->{fact}->[$ind];
 				$exists = 1;
 			} else {
 				$fact = Factory::Sub->new();
@@ -35,13 +38,18 @@ sub import {
 			$fact = Factory::Sub->new();
 		}
 		while (@factory) {
-			my ($check, $cb) = (shift(@factory), shift(@factory)); 
-			$fact->add(sub { $_[0];  }, @{$check}, $cb);
+			my ($check, $cb) = (shift(@factory), shift(@factory));
+			if (ref $check eq 'CODE') {
+				unshift @factory, $cb if $cb;
+				$fact->add($check);
+			} else {
+				$fact->add(sub { $_[0];  }, @{$check}, $cb);
+			}
 		}
 		if ($extends) {
 			Rope->clear_property($caller, $name);
 			my $prop = $meta->{properties}->{$name};
-			$prop->{fact} = $fact;
+			push @{$prop->{fact}}, $fact;
 			push @{$prop->{after}}, sub { $fact->(@_) };
 			$caller->property($name, %{$prop});	
 		} elsif (!$exists) {
@@ -50,7 +58,7 @@ sub import {
 				initable => 0,
 				enumerable => 0,
 				writeable => 0,
-				fact => $fact
+				fact => [$fact]
 			);
 		}
 	});
@@ -66,7 +74,7 @@ Rope::Factory - Rope factory properties
 
 =head1 VERSION
 
-Version 0.22
+Version 0.23
 
 =cut
 
@@ -96,6 +104,12 @@ Version 0.22
 		}
 	);
 
+	factory loop => 1 => (
+		[Str] => sub {
+			return 'chained factory ' . $_[1];
+		}
+	);
+
 	1;
 
 ...
