@@ -138,7 +138,7 @@ sub FETCH {
 					@params = $k->{value}->(@params);	
 				}
 				if ($k->{after}) {
-					@new_params = $k->{after}->(@params);
+					@new_params = ($k->{after}->(@params));
 					@params = @new_params if scalar @new_params;
 				}
 				return wantarray ? @params : $params[0];
